@@ -25,7 +25,9 @@ __all__ = (
     "IdentityProviderTypeType",
     "PortalStatusType",
     "RendererTypeType",
+    "WorkSpacesWebServiceName",
     "ServiceName",
+    "ResourceServiceName",
 )
 
 
@@ -36,6 +38,7 @@ IdentityProviderTypeType = Literal[
 ]
 PortalStatusType = Literal["Active", "Incomplete", "Pending"]
 RendererTypeType = Literal["AppStream"]
+WorkSpacesWebServiceName = Literal["workspaces-web"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -67,6 +70,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -189,6 +193,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -337,3 +342,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
