@@ -16,6 +16,7 @@ from datetime import datetime
 from typing import IO, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 from .literals import EnabledTypeType, IdentityProviderTypeType, PortalStatusType
 
@@ -195,80 +196,52 @@ AssociateUserSettingsResponseTypeDef = TypedDict(
 BrowserSettingsSummaryTypeDef = TypedDict(
     "BrowserSettingsSummaryTypeDef",
     {
-        "browserSettingsArn": str,
+        "browserSettingsArn": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredBrowserSettingsTypeDef = TypedDict(
-    "_RequiredBrowserSettingsTypeDef",
+BrowserSettingsTypeDef = TypedDict(
+    "BrowserSettingsTypeDef",
     {
         "browserSettingsArn": str,
+        "associatedPortalArns": NotRequired[List[str]],
+        "browserPolicy": NotRequired[str],
     },
 )
-_OptionalBrowserSettingsTypeDef = TypedDict(
-    "_OptionalBrowserSettingsTypeDef",
-    {
-        "associatedPortalArns": List[str],
-        "browserPolicy": str,
-    },
-    total=False,
-)
-
-
-class BrowserSettingsTypeDef(_RequiredBrowserSettingsTypeDef, _OptionalBrowserSettingsTypeDef):
-    pass
-
 
 CertificateSummaryTypeDef = TypedDict(
     "CertificateSummaryTypeDef",
     {
-        "issuer": str,
-        "notValidAfter": datetime,
-        "notValidBefore": datetime,
-        "subject": str,
-        "thumbprint": str,
+        "issuer": NotRequired[str],
+        "notValidAfter": NotRequired[datetime],
+        "notValidBefore": NotRequired[datetime],
+        "subject": NotRequired[str],
+        "thumbprint": NotRequired[str],
     },
-    total=False,
 )
 
 CertificateTypeDef = TypedDict(
     "CertificateTypeDef",
     {
-        "body": bytes,
-        "issuer": str,
-        "notValidAfter": datetime,
-        "notValidBefore": datetime,
-        "subject": str,
-        "thumbprint": str,
+        "body": NotRequired[bytes],
+        "issuer": NotRequired[str],
+        "notValidAfter": NotRequired[datetime],
+        "notValidBefore": NotRequired[datetime],
+        "subject": NotRequired[str],
+        "thumbprint": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredCreateBrowserSettingsRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateBrowserSettingsRequestRequestTypeDef",
+CreateBrowserSettingsRequestRequestTypeDef = TypedDict(
+    "CreateBrowserSettingsRequestRequestTypeDef",
     {
         "browserPolicy": str,
+        "additionalEncryptionContext": NotRequired[Mapping[str, str]],
+        "clientToken": NotRequired[str],
+        "customerManagedKey": NotRequired[str],
+        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreateBrowserSettingsRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateBrowserSettingsRequestRequestTypeDef",
-    {
-        "additionalEncryptionContext": Mapping[str, str],
-        "clientToken": str,
-        "customerManagedKey": str,
-        "tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateBrowserSettingsRequestRequestTypeDef(
-    _RequiredCreateBrowserSettingsRequestRequestTypeDef,
-    _OptionalCreateBrowserSettingsRequestRequestTypeDef,
-):
-    pass
-
 
 CreateBrowserSettingsResponseTypeDef = TypedDict(
     "CreateBrowserSettingsResponseTypeDef",
@@ -278,30 +251,16 @@ CreateBrowserSettingsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateIdentityProviderRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateIdentityProviderRequestRequestTypeDef",
+CreateIdentityProviderRequestRequestTypeDef = TypedDict(
+    "CreateIdentityProviderRequestRequestTypeDef",
     {
         "identityProviderDetails": Mapping[str, str],
         "identityProviderName": str,
         "identityProviderType": IdentityProviderTypeType,
         "portalArn": str,
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalCreateIdentityProviderRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateIdentityProviderRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class CreateIdentityProviderRequestRequestTypeDef(
-    _RequiredCreateIdentityProviderRequestRequestTypeDef,
-    _OptionalCreateIdentityProviderRequestRequestTypeDef,
-):
-    pass
-
 
 CreateIdentityProviderResponseTypeDef = TypedDict(
     "CreateIdentityProviderResponseTypeDef",
@@ -311,30 +270,16 @@ CreateIdentityProviderResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateNetworkSettingsRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateNetworkSettingsRequestRequestTypeDef",
+CreateNetworkSettingsRequestRequestTypeDef = TypedDict(
+    "CreateNetworkSettingsRequestRequestTypeDef",
     {
         "securityGroupIds": Sequence[str],
         "subnetIds": Sequence[str],
         "vpcId": str,
+        "clientToken": NotRequired[str],
+        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreateNetworkSettingsRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateNetworkSettingsRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateNetworkSettingsRequestRequestTypeDef(
-    _RequiredCreateNetworkSettingsRequestRequestTypeDef,
-    _OptionalCreateNetworkSettingsRequestRequestTypeDef,
-):
-    pass
-
 
 CreateNetworkSettingsResponseTypeDef = TypedDict(
     "CreateNetworkSettingsResponseTypeDef",
@@ -347,13 +292,12 @@ CreateNetworkSettingsResponseTypeDef = TypedDict(
 CreatePortalRequestRequestTypeDef = TypedDict(
     "CreatePortalRequestRequestTypeDef",
     {
-        "additionalEncryptionContext": Mapping[str, str],
-        "clientToken": str,
-        "customerManagedKey": str,
-        "displayName": str,
-        "tags": Sequence["TagTypeDef"],
+        "additionalEncryptionContext": NotRequired[Mapping[str, str]],
+        "clientToken": NotRequired[str],
+        "customerManagedKey": NotRequired[str],
+        "displayName": NotRequired[str],
+        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
-    total=False,
 )
 
 CreatePortalResponseTypeDef = TypedDict(
@@ -365,27 +309,14 @@ CreatePortalResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateTrustStoreRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateTrustStoreRequestRequestTypeDef",
+CreateTrustStoreRequestRequestTypeDef = TypedDict(
+    "CreateTrustStoreRequestRequestTypeDef",
     {
         "certificateList": Sequence[Union[bytes, IO[bytes], StreamingBody]],
+        "clientToken": NotRequired[str],
+        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreateTrustStoreRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateTrustStoreRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateTrustStoreRequestRequestTypeDef(
-    _RequiredCreateTrustStoreRequestRequestTypeDef, _OptionalCreateTrustStoreRequestRequestTypeDef
-):
-    pass
-
 
 CreateTrustStoreResponseTypeDef = TypedDict(
     "CreateTrustStoreResponseTypeDef",
@@ -395,32 +326,18 @@ CreateTrustStoreResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateUserSettingsRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateUserSettingsRequestRequestTypeDef",
+CreateUserSettingsRequestRequestTypeDef = TypedDict(
+    "CreateUserSettingsRequestRequestTypeDef",
     {
         "copyAllowed": EnabledTypeType,
         "downloadAllowed": EnabledTypeType,
         "pasteAllowed": EnabledTypeType,
         "printAllowed": EnabledTypeType,
         "uploadAllowed": EnabledTypeType,
+        "clientToken": NotRequired[str],
+        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreateUserSettingsRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateUserSettingsRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateUserSettingsRequestRequestTypeDef(
-    _RequiredCreateUserSettingsRequestRequestTypeDef,
-    _OptionalCreateUserSettingsRequestRequestTypeDef,
-):
-    pass
-
 
 CreateUserSettingsResponseTypeDef = TypedDict(
     "CreateUserSettingsResponseTypeDef",
@@ -626,41 +543,28 @@ GetUserSettingsResponseTypeDef = TypedDict(
 IdentityProviderSummaryTypeDef = TypedDict(
     "IdentityProviderSummaryTypeDef",
     {
-        "identityProviderArn": str,
-        "identityProviderName": str,
-        "identityProviderType": IdentityProviderTypeType,
+        "identityProviderArn": NotRequired[str],
+        "identityProviderName": NotRequired[str],
+        "identityProviderType": NotRequired[IdentityProviderTypeType],
     },
-    total=False,
 )
 
-_RequiredIdentityProviderTypeDef = TypedDict(
-    "_RequiredIdentityProviderTypeDef",
+IdentityProviderTypeDef = TypedDict(
+    "IdentityProviderTypeDef",
     {
         "identityProviderArn": str,
+        "identityProviderDetails": NotRequired[Dict[str, str]],
+        "identityProviderName": NotRequired[str],
+        "identityProviderType": NotRequired[IdentityProviderTypeType],
     },
 )
-_OptionalIdentityProviderTypeDef = TypedDict(
-    "_OptionalIdentityProviderTypeDef",
-    {
-        "identityProviderDetails": Dict[str, str],
-        "identityProviderName": str,
-        "identityProviderType": IdentityProviderTypeType,
-    },
-    total=False,
-)
-
-
-class IdentityProviderTypeDef(_RequiredIdentityProviderTypeDef, _OptionalIdentityProviderTypeDef):
-    pass
-
 
 ListBrowserSettingsRequestRequestTypeDef = TypedDict(
     "ListBrowserSettingsRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListBrowserSettingsResponseTypeDef = TypedDict(
@@ -672,28 +576,14 @@ ListBrowserSettingsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListIdentityProvidersRequestRequestTypeDef = TypedDict(
-    "_RequiredListIdentityProvidersRequestRequestTypeDef",
+ListIdentityProvidersRequestRequestTypeDef = TypedDict(
+    "ListIdentityProvidersRequestRequestTypeDef",
     {
         "portalArn": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalListIdentityProvidersRequestRequestTypeDef = TypedDict(
-    "_OptionalListIdentityProvidersRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class ListIdentityProvidersRequestRequestTypeDef(
-    _RequiredListIdentityProvidersRequestRequestTypeDef,
-    _OptionalListIdentityProvidersRequestRequestTypeDef,
-):
-    pass
-
 
 ListIdentityProvidersResponseTypeDef = TypedDict(
     "ListIdentityProvidersResponseTypeDef",
@@ -707,10 +597,9 @@ ListIdentityProvidersResponseTypeDef = TypedDict(
 ListNetworkSettingsRequestRequestTypeDef = TypedDict(
     "ListNetworkSettingsRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListNetworkSettingsResponseTypeDef = TypedDict(
@@ -725,10 +614,9 @@ ListNetworkSettingsResponseTypeDef = TypedDict(
 ListPortalsRequestRequestTypeDef = TypedDict(
     "ListPortalsRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListPortalsResponseTypeDef = TypedDict(
@@ -755,28 +643,14 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListTrustStoreCertificatesRequestRequestTypeDef = TypedDict(
-    "_RequiredListTrustStoreCertificatesRequestRequestTypeDef",
+ListTrustStoreCertificatesRequestRequestTypeDef = TypedDict(
+    "ListTrustStoreCertificatesRequestRequestTypeDef",
     {
         "trustStoreArn": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalListTrustStoreCertificatesRequestRequestTypeDef = TypedDict(
-    "_OptionalListTrustStoreCertificatesRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class ListTrustStoreCertificatesRequestRequestTypeDef(
-    _RequiredListTrustStoreCertificatesRequestRequestTypeDef,
-    _OptionalListTrustStoreCertificatesRequestRequestTypeDef,
-):
-    pass
-
 
 ListTrustStoreCertificatesResponseTypeDef = TypedDict(
     "ListTrustStoreCertificatesResponseTypeDef",
@@ -791,10 +665,9 @@ ListTrustStoreCertificatesResponseTypeDef = TypedDict(
 ListTrustStoresRequestRequestTypeDef = TypedDict(
     "ListTrustStoresRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListTrustStoresResponseTypeDef = TypedDict(
@@ -809,10 +682,9 @@ ListTrustStoresResponseTypeDef = TypedDict(
 ListUserSettingsRequestRequestTypeDef = TypedDict(
     "ListUserSettingsRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListUserSettingsResponseTypeDef = TypedDict(
@@ -827,69 +699,55 @@ ListUserSettingsResponseTypeDef = TypedDict(
 NetworkSettingsSummaryTypeDef = TypedDict(
     "NetworkSettingsSummaryTypeDef",
     {
-        "networkSettingsArn": str,
-        "vpcId": str,
+        "networkSettingsArn": NotRequired[str],
+        "vpcId": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredNetworkSettingsTypeDef = TypedDict(
-    "_RequiredNetworkSettingsTypeDef",
+NetworkSettingsTypeDef = TypedDict(
+    "NetworkSettingsTypeDef",
     {
         "networkSettingsArn": str,
+        "associatedPortalArns": NotRequired[List[str]],
+        "securityGroupIds": NotRequired[List[str]],
+        "subnetIds": NotRequired[List[str]],
+        "vpcId": NotRequired[str],
     },
 )
-_OptionalNetworkSettingsTypeDef = TypedDict(
-    "_OptionalNetworkSettingsTypeDef",
-    {
-        "associatedPortalArns": List[str],
-        "securityGroupIds": List[str],
-        "subnetIds": List[str],
-        "vpcId": str,
-    },
-    total=False,
-)
-
-
-class NetworkSettingsTypeDef(_RequiredNetworkSettingsTypeDef, _OptionalNetworkSettingsTypeDef):
-    pass
-
 
 PortalSummaryTypeDef = TypedDict(
     "PortalSummaryTypeDef",
     {
-        "browserSettingsArn": str,
-        "browserType": Literal["Chrome"],
-        "creationDate": datetime,
-        "displayName": str,
-        "networkSettingsArn": str,
-        "portalArn": str,
-        "portalEndpoint": str,
-        "portalStatus": PortalStatusType,
-        "rendererType": Literal["AppStream"],
-        "trustStoreArn": str,
-        "userSettingsArn": str,
+        "browserSettingsArn": NotRequired[str],
+        "browserType": NotRequired[Literal["Chrome"]],
+        "creationDate": NotRequired[datetime],
+        "displayName": NotRequired[str],
+        "networkSettingsArn": NotRequired[str],
+        "portalArn": NotRequired[str],
+        "portalEndpoint": NotRequired[str],
+        "portalStatus": NotRequired[PortalStatusType],
+        "rendererType": NotRequired[Literal["AppStream"]],
+        "trustStoreArn": NotRequired[str],
+        "userSettingsArn": NotRequired[str],
     },
-    total=False,
 )
 
 PortalTypeDef = TypedDict(
     "PortalTypeDef",
     {
-        "browserSettingsArn": str,
-        "browserType": Literal["Chrome"],
-        "creationDate": datetime,
-        "displayName": str,
-        "networkSettingsArn": str,
-        "portalArn": str,
-        "portalEndpoint": str,
-        "portalStatus": PortalStatusType,
-        "rendererType": Literal["AppStream"],
-        "statusReason": str,
-        "trustStoreArn": str,
-        "userSettingsArn": str,
+        "browserSettingsArn": NotRequired[str],
+        "browserType": NotRequired[Literal["Chrome"]],
+        "creationDate": NotRequired[datetime],
+        "displayName": NotRequired[str],
+        "networkSettingsArn": NotRequired[str],
+        "portalArn": NotRequired[str],
+        "portalEndpoint": NotRequired[str],
+        "portalStatus": NotRequired[PortalStatusType],
+        "rendererType": NotRequired[Literal["AppStream"]],
+        "statusReason": NotRequired[str],
+        "trustStoreArn": NotRequired[str],
+        "userSettingsArn": NotRequired[str],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -903,27 +761,14 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredTagResourceRequestRequestTypeDef = TypedDict(
-    "_RequiredTagResourceRequestRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
         "tags": Sequence["TagTypeDef"],
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalTagResourceRequestRequestTypeDef = TypedDict(
-    "_OptionalTagResourceRequestRequestTypeDef",
-    {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class TagResourceRequestRequestTypeDef(
-    _RequiredTagResourceRequestRequestTypeDef, _OptionalTagResourceRequestRequestTypeDef
-):
-    pass
-
 
 TagTypeDef = TypedDict(
     "TagTypeDef",
@@ -936,18 +781,16 @@ TagTypeDef = TypedDict(
 TrustStoreSummaryTypeDef = TypedDict(
     "TrustStoreSummaryTypeDef",
     {
-        "trustStoreArn": str,
+        "trustStoreArn": NotRequired[str],
     },
-    total=False,
 )
 
 TrustStoreTypeDef = TypedDict(
     "TrustStoreTypeDef",
     {
-        "associatedPortalArns": List[str],
-        "trustStoreArn": str,
+        "associatedPortalArns": NotRequired[List[str]],
+        "trustStoreArn": NotRequired[str],
     },
-    total=False,
 )
 
 UntagResourceRequestRequestTypeDef = TypedDict(
@@ -958,28 +801,14 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateBrowserSettingsRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateBrowserSettingsRequestRequestTypeDef",
+UpdateBrowserSettingsRequestRequestTypeDef = TypedDict(
+    "UpdateBrowserSettingsRequestRequestTypeDef",
     {
         "browserSettingsArn": str,
+        "browserPolicy": NotRequired[str],
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalUpdateBrowserSettingsRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateBrowserSettingsRequestRequestTypeDef",
-    {
-        "browserPolicy": str,
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class UpdateBrowserSettingsRequestRequestTypeDef(
-    _RequiredUpdateBrowserSettingsRequestRequestTypeDef,
-    _OptionalUpdateBrowserSettingsRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateBrowserSettingsResponseTypeDef = TypedDict(
     "UpdateBrowserSettingsResponseTypeDef",
@@ -989,30 +818,16 @@ UpdateBrowserSettingsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateIdentityProviderRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateIdentityProviderRequestRequestTypeDef",
+UpdateIdentityProviderRequestRequestTypeDef = TypedDict(
+    "UpdateIdentityProviderRequestRequestTypeDef",
     {
         "identityProviderArn": str,
+        "clientToken": NotRequired[str],
+        "identityProviderDetails": NotRequired[Mapping[str, str]],
+        "identityProviderName": NotRequired[str],
+        "identityProviderType": NotRequired[IdentityProviderTypeType],
     },
 )
-_OptionalUpdateIdentityProviderRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateIdentityProviderRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "identityProviderDetails": Mapping[str, str],
-        "identityProviderName": str,
-        "identityProviderType": IdentityProviderTypeType,
-    },
-    total=False,
-)
-
-
-class UpdateIdentityProviderRequestRequestTypeDef(
-    _RequiredUpdateIdentityProviderRequestRequestTypeDef,
-    _OptionalUpdateIdentityProviderRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateIdentityProviderResponseTypeDef = TypedDict(
     "UpdateIdentityProviderResponseTypeDef",
@@ -1022,30 +837,16 @@ UpdateIdentityProviderResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateNetworkSettingsRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateNetworkSettingsRequestRequestTypeDef",
+UpdateNetworkSettingsRequestRequestTypeDef = TypedDict(
+    "UpdateNetworkSettingsRequestRequestTypeDef",
     {
         "networkSettingsArn": str,
+        "clientToken": NotRequired[str],
+        "securityGroupIds": NotRequired[Sequence[str]],
+        "subnetIds": NotRequired[Sequence[str]],
+        "vpcId": NotRequired[str],
     },
 )
-_OptionalUpdateNetworkSettingsRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateNetworkSettingsRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "securityGroupIds": Sequence[str],
-        "subnetIds": Sequence[str],
-        "vpcId": str,
-    },
-    total=False,
-)
-
-
-class UpdateNetworkSettingsRequestRequestTypeDef(
-    _RequiredUpdateNetworkSettingsRequestRequestTypeDef,
-    _OptionalUpdateNetworkSettingsRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateNetworkSettingsResponseTypeDef = TypedDict(
     "UpdateNetworkSettingsResponseTypeDef",
@@ -1055,26 +856,13 @@ UpdateNetworkSettingsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdatePortalRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdatePortalRequestRequestTypeDef",
+UpdatePortalRequestRequestTypeDef = TypedDict(
+    "UpdatePortalRequestRequestTypeDef",
     {
         "portalArn": str,
+        "displayName": NotRequired[str],
     },
 )
-_OptionalUpdatePortalRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdatePortalRequestRequestTypeDef",
-    {
-        "displayName": str,
-    },
-    total=False,
-)
-
-
-class UpdatePortalRequestRequestTypeDef(
-    _RequiredUpdatePortalRequestRequestTypeDef, _OptionalUpdatePortalRequestRequestTypeDef
-):
-    pass
-
 
 UpdatePortalResponseTypeDef = TypedDict(
     "UpdatePortalResponseTypeDef",
@@ -1084,28 +872,15 @@ UpdatePortalResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateTrustStoreRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateTrustStoreRequestRequestTypeDef",
+UpdateTrustStoreRequestRequestTypeDef = TypedDict(
+    "UpdateTrustStoreRequestRequestTypeDef",
     {
         "trustStoreArn": str,
+        "certificatesToAdd": NotRequired[Sequence[Union[bytes, IO[bytes], StreamingBody]]],
+        "certificatesToDelete": NotRequired[Sequence[str]],
+        "clientToken": NotRequired[str],
     },
 )
-_OptionalUpdateTrustStoreRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateTrustStoreRequestRequestTypeDef",
-    {
-        "certificatesToAdd": Sequence[Union[bytes, IO[bytes], StreamingBody]],
-        "certificatesToDelete": Sequence[str],
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class UpdateTrustStoreRequestRequestTypeDef(
-    _RequiredUpdateTrustStoreRequestRequestTypeDef, _OptionalUpdateTrustStoreRequestRequestTypeDef
-):
-    pass
-
 
 UpdateTrustStoreResponseTypeDef = TypedDict(
     "UpdateTrustStoreResponseTypeDef",
@@ -1115,32 +890,18 @@ UpdateTrustStoreResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateUserSettingsRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateUserSettingsRequestRequestTypeDef",
+UpdateUserSettingsRequestRequestTypeDef = TypedDict(
+    "UpdateUserSettingsRequestRequestTypeDef",
     {
         "userSettingsArn": str,
+        "clientToken": NotRequired[str],
+        "copyAllowed": NotRequired[EnabledTypeType],
+        "downloadAllowed": NotRequired[EnabledTypeType],
+        "pasteAllowed": NotRequired[EnabledTypeType],
+        "printAllowed": NotRequired[EnabledTypeType],
+        "uploadAllowed": NotRequired[EnabledTypeType],
     },
 )
-_OptionalUpdateUserSettingsRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateUserSettingsRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "copyAllowed": EnabledTypeType,
-        "downloadAllowed": EnabledTypeType,
-        "pasteAllowed": EnabledTypeType,
-        "printAllowed": EnabledTypeType,
-        "uploadAllowed": EnabledTypeType,
-    },
-    total=False,
-)
-
-
-class UpdateUserSettingsRequestRequestTypeDef(
-    _RequiredUpdateUserSettingsRequestRequestTypeDef,
-    _OptionalUpdateUserSettingsRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateUserSettingsResponseTypeDef = TypedDict(
     "UpdateUserSettingsResponseTypeDef",
@@ -1153,35 +914,24 @@ UpdateUserSettingsResponseTypeDef = TypedDict(
 UserSettingsSummaryTypeDef = TypedDict(
     "UserSettingsSummaryTypeDef",
     {
-        "copyAllowed": EnabledTypeType,
-        "downloadAllowed": EnabledTypeType,
-        "pasteAllowed": EnabledTypeType,
-        "printAllowed": EnabledTypeType,
-        "uploadAllowed": EnabledTypeType,
-        "userSettingsArn": str,
+        "copyAllowed": NotRequired[EnabledTypeType],
+        "downloadAllowed": NotRequired[EnabledTypeType],
+        "pasteAllowed": NotRequired[EnabledTypeType],
+        "printAllowed": NotRequired[EnabledTypeType],
+        "uploadAllowed": NotRequired[EnabledTypeType],
+        "userSettingsArn": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredUserSettingsTypeDef = TypedDict(
-    "_RequiredUserSettingsTypeDef",
+UserSettingsTypeDef = TypedDict(
+    "UserSettingsTypeDef",
     {
         "userSettingsArn": str,
+        "associatedPortalArns": NotRequired[List[str]],
+        "copyAllowed": NotRequired[EnabledTypeType],
+        "downloadAllowed": NotRequired[EnabledTypeType],
+        "pasteAllowed": NotRequired[EnabledTypeType],
+        "printAllowed": NotRequired[EnabledTypeType],
+        "uploadAllowed": NotRequired[EnabledTypeType],
     },
 )
-_OptionalUserSettingsTypeDef = TypedDict(
-    "_OptionalUserSettingsTypeDef",
-    {
-        "associatedPortalArns": List[str],
-        "copyAllowed": EnabledTypeType,
-        "downloadAllowed": EnabledTypeType,
-        "pasteAllowed": EnabledTypeType,
-        "printAllowed": EnabledTypeType,
-        "uploadAllowed": EnabledTypeType,
-    },
-    total=False,
-)
-
-
-class UserSettingsTypeDef(_RequiredUserSettingsTypeDef, _OptionalUserSettingsTypeDef):
-    pass
